@@ -5,19 +5,11 @@
 import re
 from time import sleep
 
-import boto3
 from boto3.session import Session
 
 try:
-    from ecr_scan_reporter.ecr_scan_reporter import (
-        DEFAULT_THRESHOLDS,
-        parse_scan_report,
-    )
-    from ecr_scan_reporter.images_scanner import (
-        define_images_to_scan,
-        list_all_images,
-        trigger_images_scan,
-    )
+    from ecr_scan_reporter.ecr_scan_reporter import DEFAULT_THRESHOLDS
+    from ecr_scan_reporter.images_scanner import list_all_images, trigger_images_scan
 except ImportError:
     raise ImportError(
         "You must install ecr-scan-reporter in order to use this functionality"
@@ -90,7 +82,9 @@ def scan_poll_and_wait(registry, repository_name, image, image_url, ecr_session=
     while True:
         try:
             image_scan_r = client.describe_image_scan_findings(
-                registryId=registry, repositoryName=repository_name, imageId=image
+                registryId=registry,
+                repositoryName=repository_name,
+                imageId=image,
             )
             if image_scan_r["imageScanStatus"]["status"] == "IN_PROGRESS":
                 LOG.info(f"{image_url} - Scan in progress - waiting 10 seconds")
@@ -103,7 +97,12 @@ def scan_poll_and_wait(registry, repository_name, image, image_url, ecr_session=
 
 
 def wait_for_scan_report(
-    registry, repository_name, image, image_url, trigger_scan=False, ecr_session=None
+    registry,
+    repository_name,
+    image,
+    image_url,
+    trigger_scan=False,
+    ecr_session=None,
 ):
     """
     Function to wait for the scan report to go from In Progress to else
@@ -146,19 +145,22 @@ def wait_for_scan_report(
     return findings
 
 
-def validate_image_from_ecr(service):
+def invalidate_image_from_ecr(service, mute=False):
     """
     Function to validate that the image URI is from valid and from private ECR
 
     :param ecs_composex.common.compose_services.ComposeService service:
-    :return:
+    :param bool mute: Whether we display output
+    :return: True when the image is not from ECR
+    :rtype: bool
     """
     if not ECR_URI_RE.match(service.image):
-        LOG.info(
-            f"{service.name} - image provided not valid ECR URI - "
-            f"{service.image} - "
-        )
-        LOG.info(f"Expected ECR Regexp {ECR_URI_RE.pattern}")
+        if not mute:
+            LOG.info(
+                f"{service.name} - image provided not valid ECR URI - "
+                f"{service.image} - "
+            )
+            LOG.info(f"Expected ECR Regexp {ECR_URI_RE.pattern}")
         return True
     return False
 
@@ -176,7 +178,7 @@ def validate_input(service):
     if not keyisset("VulnerabilitiesScan", service.ecr_config):
         LOG.info(f"{service.name} - No scan to be evaluated.")
         return True
-    if validate_image_from_ecr(service):
+    if invalidate_image_from_ecr(service, True):
         return True
     return False
 
@@ -268,6 +270,8 @@ def define_result(image_url, security_findings, thresholds, vulnerability_config
                 )
                 if not keyisset("IgnoreFailure", vulnerability_config):
                     result = True
+    LOG.info("ECR Scan Thresholds")
+    LOG.info(",".join([f"{name}/{limit}" for name, limit in thresholds.items()]))
     return result
 
 
@@ -295,7 +299,7 @@ def define_service_image(service, settings):
     :return:
     """
     current_account_id = settings.session.client("sts").get_caller_identity()["Account"]
-    if validate_image_from_ecr(service):
+    if invalidate_image_from_ecr(service):
         return
     image_sha = None
     image_tag = None
