@@ -24,5 +24,8 @@ from ecs_composex import __version__ as version
 
 metadata = {
     "Type": "ComposeX",
-    "Properties": {"ecs_composex::module": "ecs_composex.ecs", "Version": version},
+    "Properties": {
+        "ecs_composex::module": "ecs_composex.ecs",
+        "Version": version,
+    },
 }
