@@ -12,7 +12,7 @@ which it heavily relies onto.
 You can change the names *values* so you like so long as you keep it Alphanumerical [a-zA-Z0-9]
 """
 
-from troposphere import And, Condition, Equals, Not, Ref
+from troposphere import And, Condition, Equals, Not, Or, Ref
 
 from ecs_composex.ecs import ecs_params
 
@@ -27,9 +27,29 @@ USE_CLUSTER_SG_CON = Not(Condition(NOT_USE_CLUSTER_SG_CON_T))
 SERVICE_COUNT_ZERO_CON_T = "ServiceCountIsZeroCondition"
 SERVICE_COUNT_ZERO_CON = Equals(Ref(ecs_params.SERVICE_COUNT), "0")
 
-USE_FARGATE_CON_T = "UseFargateCondition"
+USE_EC2_CON_T = "UseBasicLaunchTypeCondition"
+USE_EC2_CON = Equals(Ref(ecs_params.LAUNCH_TYPE), "EC2")
+
+USE_FARGATE_CON_T = "UseFargateLaunchTypeCondition"
 USE_FARGATE_CON = Equals(Ref(ecs_params.LAUNCH_TYPE), "FARGATE")
 
+USE_NORMAL_LAUNCH_TYPES_CON_T = "UseNormalLaunchType"
+USE_NORMAL_LAUNCH_TYPES_CON = Or(Condition(USE_EC2_CON_T), Condition(USE_FARGATE_CON_T))
+
+USE_FARGATE_PROVIDERS_CON_T = "UseFargateProvidersCondition"
+USE_FARGATE_PROVIDERS_CON = Equals(Ref(ecs_params.LAUNCH_TYPE), "FARGATE_PROVIDERS")
+
+USE_MIXED_CAPACITY_PROVIDERS_CON_T = "UseMixedProvidersCondition"
+USE_MIXED_CAPACITY_PROVIDERS_CON = Equals(
+    Ref(ecs_params.LAUNCH_TYPE), "CAPACITY_PROVIDERS"
+)
+
+USE_SOME_CAPACITY_PROVIDER_CON_T = "UseSomeCapacityProviderCondition"
+USE_SOME_CAPACITY_PROVIDER_CON = Or(
+    Condition(USE_FARGATE_PROVIDERS_CON_T),
+    Condition(USE_MIXED_CAPACITY_PROVIDERS_CON_T),
+)
+
 SERVICE_COUNT_ZERO_AND_FARGATE_CON_T = "ServiceCountZeroAndFargate"
 SERVICE_COUNT_ZERO_AND_FARGATE_CON = And(
     Condition(USE_FARGATE_CON_T), Condition(SERVICE_COUNT_ZERO_CON_T)
@@ -43,14 +63,6 @@ NOT_USE_HOSTNAME_CON = Equals(
 USE_HOSTNAME_CON_T = "UseMicroserviceHostnameCondition"
 USE_HOSTNAME_CON = Not(Condition(NOT_USE_HOSTNAME_CON_T))
 
-USE_CLUSTER_CAPACITY_PROVIDERS_CON_T = "UseClusterDefaultCapacityProviders"
-USE_CLUSTER_CAPACITY_PROVIDERS_CON = Not(Equals(Ref(ecs_params.LAUNCH_TYPE), "EC2"))
-
-NOT_USE_CLUSTER_CAPACITY_PROVIDERS_CON_T = "UseCustomCapacityProvidersCon"
-NOT_USE_CLUSTER_CAPACITY_PROVIDERS_CON = Equals(
-    Ref(ecs_params.LAUNCH_TYPE), "CAPACITY_PROVIDERS"
-)
-
 CREATE_CLUSTER_CON_T = "CreateClusterCondition"
 CREATE_CLUSTER_CON = Equals(Ref(ecs_params.CREATE_CLUSTER), "True")
 GENERATED_CLUSTER_NAME_CON_T = "GenerateEcsClusterName"
