@@ -13,22 +13,6 @@ from ecs_composex.common import LOG
 ROLE_ARN_ARG = "RoleArn"
 
 
-def validate_iam_role_arn(arn):
-    """
-    Function to validate IAM ROLE ARN format
-    :param str arn:
-    :return: resource match
-    :rtype: re.match
-    """
-    arn_valid = re.compile(r"^arn:aws(?:-[a-z]+)?:iam::[0-9]{12}:role/[\S]+$")
-    if not arn_valid.match(arn):
-        raise ValueError(
-            "The role ARN needs to be a valid ARN of format",
-            arn_valid.pattern,
-        )
-    return arn_valid.match(arn)
-
-
 def service_role_trust_policy(service_name):
     """
     Simple function to format the trust relationship for a Role and an AWS Service
@@ -58,7 +42,8 @@ def define_iam_policy(policy):
 
     if not policy_re.match(policy):
         raise ValueError(
-            f"policy name {policy} does not match expected regexp", policy_re.pattern
+            f"policy name {policy} does not match expected regexp",
+            policy_re.pattern,
         )
     if isinstance(policy, str) and not policy.startswith("arn:aws:iam::"):
         policy_def = Sub(
